import { DeepComplete, DeepUndefinedToNull, UnboxedDto, UnboxedNoNullsDto } from "@upload-io/upload-shared-iso";
export declare class IsoObjectUtils {
    /**
     * Coverts 'undefined' on boxed to 'null' in unboxed.
     */
    static box<TBoxedDto, TUnboxedDto extends UnboxedDto<TBoxedDto> = UnboxedDto<TBoxedDto>>(unboxedDto: TUnboxedDto): TBoxedDto;
    /**
     * Keeps 'undefined' on boxed as 'undefined' (i.e. optional property) in unboxed.
     */
    static boxNoNullConversion<TBoxedDto, TUnboxedDto extends UnboxedNoNullsDto<TBoxedDto> = UnboxedNoNullsDto<TBoxedDto>>(unboxedDto: TUnboxedDto): TBoxedDto;
    /**
     * Converts 'foo?: Type' to 'foo: Type | undefined'
     */
    static complete<T>(value: T): DeepComplete<T>;
    static nullToUndefined<T>(obj: T): DeepUndefinedToNull<T>;
    static fullOuterJoin<K extends string, V>(left: Record<K, V | undefined>, right: Record<K, V | undefined>, reduce: (left: V, right: V) => V): Record<K, V>;
    static unbox<T>(boxedDto: T): DeepUndefinedToNull<T>;
    static undefinedToNull<T>(obj: T): DeepUndefinedToNull<T>;
    private static replace;
}
