/**
 * Nominally-typed primitive types.
 *
 * See:
 * - https://basarat.gitbook.io/typescript/main-1/nominaltyping#using-interfaces
 * - https://github.com/Microsoft/TypeScript/blob/7b48a182c05ea4dea81bab73ecbbe9e013a79e99/src/compiler/types.ts#L693-L698
 */
import { Opaque } from "ts-essentials";
export declare type AscDesc = "asc" | "desc";
export declare function maybe<A, B>(box: (value: B) => A, value: B | undefined): A | undefined;
export declare type OriginRequestPath = Opaque<string, "OriginRequestPath">;
export declare function OriginRequestPath(value: string): OriginRequestPath;
export declare type UseInternalStorage = Opaque<boolean, "UseInternalStorage">;
export declare function UseInternalStorage(value: boolean): UseInternalStorage;
export declare type OriginRequestTransformationHeaderValue = Opaque<string, "OriginRequestTransformationHeaderValue">;
export declare function OriginRequestTransformationHeaderValue(value: string): OriginRequestTransformationHeaderValue;
export declare type MediaConvertJobId = Opaque<string, "MediaConvertJobId">;
export declare function MediaConvertJobId(value: string): MediaConvertJobId;
export declare type MediaConvertErrorCode = Opaque<number, "MediaConvertErrorCode">;
export declare function MediaConvertErrorCode(value: number): MediaConvertErrorCode;
export declare type UploadCdnBaseUrl = Opaque<string, "UploadCdnBaseUrl">;
export declare function UploadCdnBaseUrl(value: string): UploadCdnBaseUrl;
export declare type TransformationRootPath = Opaque<string, "TransformationRootPath">;
export declare function TransformationRootPath(value: string): TransformationRootPath;
export declare type OrganizationName = Opaque<string, "OrganizationName">;
export declare function OrganizationName(value: string): OrganizationName;
export declare type DepartmentName = Opaque<string, "DepartmentName">;
export declare function DepartmentName(value: string): DepartmentName;
export declare type WorkflowName = Opaque<string, "WorkflowName">;
export declare function WorkflowName(value: string): WorkflowName;
export declare type WorkflowInterpolatedString = Opaque<string, "WorkflowInterpolatedString">;
export declare function WorkflowInterpolatedString(value: string): WorkflowInterpolatedString;
/**
 * A custom JSON path syntax that supports GETS and SETS:
 *
 * $.someField.someSubField[0].foo
 *
 * JMESPath and JSONPath do not allow SETs since their expressions can match multiple leafs in the JSON graph.
 */
export declare type WorkflowContextPath = Opaque<string, "WorkflowContextPath">;
export declare function WorkflowContextPath(value: string): WorkflowContextPath;
export declare type WorkflowStepName = Opaque<string, "WorkflowStepName">;
export declare function WorkflowStepName(value: string): WorkflowStepName;
export declare type WorkflowActionName = Opaque<string, "WorkflowActionName">;
export declare function WorkflowActionName(value: string): WorkflowActionName;
export declare type AccountId = Opaque<string, "AccountId">;
export declare function AccountId(value: string): AccountId;
export declare type AccountJobId = Opaque<string, "AccountJobId">;
export declare function AccountJobId(value: string): AccountJobId;
export declare type FileId = Opaque<string, "FileId">;
export declare function FileId(value: string): FileId;
export declare type StringWithWorkflowVariables = Opaque<string, "StringWithWorkflowVariables">;
export declare function StringWithWorkflowVariables(value: string): StringWithWorkflowVariables;
export declare type FileUniquifier = Opaque<string, "FileUniquifier">;
export declare function FileUniquifier(value: string): FileUniquifier;
export declare type UserId = Opaque<string, "UserId">;
export declare function UserId(value: string): UserId;
export declare type MailChimpContactId = Opaque<string, "MailChimpContactId">;
export declare function MailChimpContactId(value: string): MailChimpContactId;
export declare type PaddleSubscriptionId = Opaque<number, "PaddleSubscriptionId">;
export declare function PaddleSubscriptionId(value: number): PaddleSubscriptionId;
export declare type ScheduledEventBucketId = Opaque<number, "ScheduledEventBucketId">;
export declare function ScheduledEventBucketId(value: number): ScheduledEventBucketId;
export declare type ScheduledEventShardCount = Opaque<number, "ScheduledEventShardCount">;
export declare function ScheduledEventShardCount(value: number): ScheduledEventShardCount;
export declare type ScheduledEventShardIndex = Opaque<number, "ScheduledEventShardIndex">;
export declare function ScheduledEventShardIndex(value: number): ScheduledEventShardIndex;
export declare type PaddleVendorId = Opaque<number, "PaddleVendorId">;
export declare function PaddleVendorId(value: number): PaddleVendorId;
export declare type PaddleAuthCode = Opaque<string, "PaddleAuthCode">;
export declare function PaddleAuthCode(value: string): PaddleAuthCode;
export declare type MailChimpApiKey = Opaque<string, "MailChimpApiKey">;
export declare function MailChimpApiKey(value: string): MailChimpApiKey;
export declare type SubscriptionNonce = Opaque<string, "SubscriptionNonce">;
export declare function SubscriptionNonce(value: string): SubscriptionNonce;
export declare type Uuid = Opaque<string, "Uuid">;
export declare function Uuid(value: string): Uuid;
export declare type FileListShard = Opaque<number, "FileListShard">;
export declare function FileListShard(value: number): FileListShard;
export declare type ProcessId = Opaque<number, "ProcessId">;
export declare function ProcessId(value: number): ProcessId;
/**
 * SPID and TID (Thread ID) are used interchangeably on Linux, and describe thread IDs. Each process has at least one
 * thread, and that thread has a SPID (thread ID) that matches the process's PID. The process may then have additional SPIDs/threads.
 */
export declare type SPID = Opaque<number, "SPID">;
export declare function SPID(value: number): SPID;
export declare type FileListShardCount = Opaque<number, "FileListShardCount">;
export declare function FileListShardCount(value: number): FileListShardCount;
export declare type StorageEventShard = Opaque<number, "StorageEventShard">;
export declare function StorageEventShard(value: number): StorageEventShard;
export declare type StorageEventShardCount = Opaque<number, "StorageEventShardCount">;
export declare function StorageEventShardCount(value: number): StorageEventShardCount;
export declare type TransformationEventShard = Opaque<number, "TransformationEventShard">;
export declare function TransformationEventShard(value: number): TransformationEventShard;
export declare type TransformationEventShardCount = Opaque<number, "TransformationEventShardCount">;
export declare function TransformationEventShardCount(value: number): TransformationEventShardCount;
export declare type PostHogApiKey = Opaque<string, "PostHogApiKey">;
export declare function PostHogApiKey(value: string): PostHogApiKey;
export declare type DownloadEventShard = Opaque<number, "DownloadEventShard">;
export declare function DownloadEventShard(value: number): DownloadEventShard;
export declare type DownloadEventShardCount = Opaque<number, "DownloadEventShardCount">;
export declare function DownloadEventShardCount(value: number): DownloadEventShardCount;
export declare type EventType = Opaque<string, "EventType">;
export declare function EventType(value: string): EventType;
export declare type UploadPartIndex = Opaque<number, "UploadPartIndex">;
export declare function UploadPartIndex(value: number): UploadPartIndex;
export declare type TransformerAccessToken = Opaque<string, "TransformerAccessToken">;
export declare function TransformerAccessToken(value: string): TransformerAccessToken;
/**
 * Artifacts are accessible artifacts of the transformation.
 *
 * Contains a '/' prefix.
 */
export declare type TransformationArtifactPath = Opaque<string, "TransformationArtifactPath">;
export declare function TransformationArtifactPath(value: string): TransformationArtifactPath;
/**
 * Buffers are files produced by services like MediaConvert in S3, and may become the input to the next phase in a
 * transformation (e.g. a video thumbnail, which then has further processing performed by the Image Processing API),
 * or may simply be discarded, or may be promoted as artifacts of the transformation.
 *
 * Contains a '/' prefix.
 */
export declare type TransformationBufferPath = Opaque<string, "TransformationBufferPath">;
export declare function TransformationBufferPath(value: string): TransformationBufferPath;
export declare type RequestId = Opaque<string, "RequestId">;
export declare function RequestId(value: string): RequestId;
export declare type TransformationFunctionSignature = Opaque<string, "TransformationFunctionSignature">;
export declare function TransformationFunctionSignature(value: string): TransformationFunctionSignature;
export declare type TrustZoneId = Opaque<string, "TrustZoneId">;
export declare function TrustZoneId(value: string): TrustZoneId;
export declare type LambdaFunctionName = Opaque<string, "LambdaFunctionName">;
export declare function LambdaFunctionName(value: string): LambdaFunctionName;
export declare type NpmPackageName = Opaque<string, "NpmPackageName">;
export declare function NpmPackageName(value: string): NpmPackageName;
export declare type NpmPackageVersion = Opaque<string, "NpmPackageVersion">;
export declare function NpmPackageVersion(value: string): NpmPackageVersion;
export declare type NpmUsername = Opaque<string, "NpmUsername">;
export declare function NpmUsername(value: string): NpmUsername;
export declare type CacheId = Opaque<string, "CacheId">;
export declare function CacheId(value: string): CacheId;
export declare type Stage = Opaque<string, "Stage">;
export declare function Stage(value: string): Stage;
export declare type LogGroupName = Opaque<string, "LogGroupName">;
export declare function LogGroupName(value: string): LogGroupName;
/**
 * Globally unique transformation invocation ID (as opposed to a function-local invocation ID).
 */
export declare type GlobalTransformationInvocationId = Opaque<string, "GlobalTransformationInvocationId">;
export declare function GlobalTransformationInvocationId(value: string): GlobalTransformationInvocationId;
export declare type RoleArn = Opaque<string, "RoleArn">;
export declare function RoleArn(value: string): RoleArn;
export declare type SesEmailDomainArn = Opaque<string, "SesEmailDomainArn">;
export declare function SesEmailDomainArn(value: string): SesEmailDomainArn;
export declare type DynamoDBTableName = Opaque<string, "DynamoDBTableName">;
export declare function DynamoDBTableName(value: string): DynamoDBTableName;
export declare type KinesisShardId = Opaque<string, "KinesisShardId">;
export declare function KinesisShardId(value: string): KinesisShardId;
export declare type KinesisPartitionKey = Opaque<string, "KinesisPartitionKey">;
export declare function KinesisPartitionKey(value: string): KinesisPartitionKey;
export declare type KinesisStreamName = Opaque<string, "KinesisStreamName">;
export declare function KinesisStreamName(value: string): KinesisStreamName;
export declare type SQSQueueUrl = Opaque<string, "SQSQueueUrl">;
export declare function SQSQueueUrl(value: string): SQSQueueUrl;
export declare type CloudWatchLogEventId = Opaque<string, "CloudWatchLogEventId">;
export declare function CloudWatchLogEventId(value: string): CloudWatchLogEventId;
export declare type SentryDsn = Opaque<string, "SentryDsn">;
export declare function SentryDsn(value: string): SentryDsn;
export declare type CloudFrontDistributionId = Opaque<string, "CloudFrontDistributionId">;
export declare function CloudFrontDistributionId(value: string): CloudFrontDistributionId;
export declare type AwsRegion = Opaque<string, "AwsRegion">;
export declare function AwsRegion(value: string): AwsRegion;
export declare type AwsAccessKey = Opaque<string, "AwsAccessKey">;
export declare function AwsAccessKey(value: string): AwsAccessKey;
export declare type AwsSecretKey = Opaque<string, "AwsSecretKey">;
export declare function AwsSecretKey(value: string): AwsSecretKey;
export declare type S3BucketName = Opaque<string, "S3BucketName">;
export declare function S3BucketName(value: string): S3BucketName;
export declare type DigitalOceanRegion = Opaque<string, "DigitalOceanRegion">;
export declare function DigitalOceanRegion(value: string): DigitalOceanRegion;
export declare type CognitoUserPoolId = Opaque<string, "CognitoUserPoolId">;
export declare function CognitoUserPoolId(value: string): CognitoUserPoolId;
export declare type CognitoUserPoolClientId = Opaque<string, "CognitoUserPoolClientId">;
export declare function CognitoUserPoolClientId(value: string): CognitoUserPoolClientId;
export declare type EventId = Opaque<string, "EventId">;
export declare function EventId(value: string): EventId;
/**
 * Reflects the order in which an event was published onto a stream. Any two events can be causally ordered based on
 * this number (unlike the event ID, which is granular only down to millisecond-level, and may drift between servers).
 * We store as 'string' instead of 'BigInt' since the latter causes serialization issues in various libraries (e.g. Pino
 * and possibly DynamoDB)... **but for comparison between serial numbers you should first convert to BigInt**
 */
export declare type EventSequenceNumber = Opaque<string, "EventSequenceNumber">;
export declare function EventSequenceNumber(value: string): EventSequenceNumber;
export declare type OriginalFileName = Opaque<string, "OriginalFileName">;
export declare function OriginalFileName(value: string): OriginalFileName;
/**
 * Do NOT start with a '/' prefix.
 */
export declare type S3ObjectKey = Opaque<string, "S3ObjectKey">;
export declare function S3ObjectKey(value: string): S3ObjectKey;
/**
 * This is NOT a full S3 object key!
 *
 * This is instead something we've invented:
 *
 * - If the object is a file, the value will not contain any "/" characters, e.g. "foo".
 *
 * - If the object is a folder, the value will contain a "/" suffix and no other "/" characters, e.g. "foo/"
 *
 * - If the object is a nameless folder, the value will be "/".
 */
export declare type S3ObjectName = Opaque<string, "S3ObjectName">;
export declare function S3ObjectName(value: string): S3ObjectName;
export declare type S3MultipartUploadId = Opaque<string, "S3MultipartUploadId">;
export declare function S3MultipartUploadId(value: string): S3MultipartUploadId;
export declare type UploadId = Opaque<string, "UploadId">;
export declare function UploadId(value: string): UploadId;
/**
 * 1 = 100%
 *
 * Can be greater than 1.
 */
export declare type Factor = Opaque<number, "Factor">;
export declare function Factor(value: number): Factor;
/**
 * ETags are always wrapped in quotes (https://tools.ietf.org/html/rfc2616#section-14.19). However, we don't enforce
 * this and we don't inspect this. In this codebase, ETags are always given to us by S3: we don't try to remove these
 * quotes to save 4 characters of storage per file (since in JSON this serializes to "\"xyz\"") because unwrapping and
 * then re-wrapping again (for the call back to S3) creates a larger surface area for bugs: we simply tunnel what S3
 * provides to the client, to our API, then to S3 again from the API's side, as a blackbox parameter.
 */
export declare type ETag = Opaque<string, "ETag">;
export declare function ETag(value: string): ETag;
/**
 * URL for an http(s) resource.
 */
export declare type HttpUrl = Opaque<string, "HttpUrl">;
export declare function HttpUrl(value: string): HttpUrl;
export declare type HttpUrlAbsoluteOrRelative = Opaque<string, "HttpUrlAbsoluteOrRelative">;
export declare function HttpUrlAbsoluteOrRelative(value: string): HttpUrlAbsoluteOrRelative;
export declare type HttpUrlNoHost = Opaque<string, "HttpUrlNoHost">;
export declare function HttpUrlNoHost(value: string): HttpUrlNoHost;
/**
 * URL for an http(s) resource WITHOUT the path, e.g. "https://upload.io"
 */
export declare type HttpOrigin = Opaque<string, "HttpOrigin">;
export declare function HttpOrigin(value: string): HttpOrigin;
export declare type EmailAddress = Opaque<string, "EmailAddress">;
export declare function EmailAddress(value: string): EmailAddress;
export declare type FirstName = Opaque<string, "FirstName">;
export declare function FirstName(value: string): FirstName;
export declare type LastName = Opaque<string, "LastName">;
export declare function LastName(value: string): LastName;
export declare type FSFilePath = Opaque<string, "FSFilePath">;
export declare function FSFilePath(value: string): FSFilePath;
export declare type TcpPort = Opaque<number, "TcpPort">;
export declare function TcpPort(value: number): TcpPort;
export declare type DistributedLockId = Opaque<string, "DistributedLockId">;
export declare function DistributedLockId(value: string): DistributedLockId;
export declare type DistributedLockOwner = Opaque<string, "DistributedLockOwner">;
export declare function DistributedLockOwner(value: string): DistributedLockOwner;
/**
 * Unique within the scope of a single account only. Not guaranteed to be unique globally. Does not contain the
 * account ID as a prefix, so must accompany an account ID for the purpose of identifying a public key.
 */
export declare type PublicKeyId = Opaque<string, "PublicKeyId">;
export declare function PublicKeyId(value: string): PublicKeyId;
export declare type PublicKeyName = Opaque<string, "PublicKeyName">;
export declare function PublicKeyName(value: string): PublicKeyName;
/**
 * Public key in PEM format: "-----BEGIN PUBLIC KEY-----...-----END PUBLIC KEY-----"
 */
export declare type PublicKeyPEM = Opaque<string, "PublicKeyPEM">;
export declare function PublicKeyPEM(value: string): PublicKeyPEM;
/**
 * Public key in PEM format: "-----BEGIN RSA PRIVATE KEY-----...-----END RSA PRIVATE KEY-----"
 */
export declare type PrivateKeyPEM = Opaque<string, "PrivateKeyPEM">;
export declare function PrivateKeyPEM(value: string): PrivateKeyPEM;
export declare type Base64 = Opaque<string, "Base64">;
export declare function Base64(value: string): Base64;
/**
 * Base64-encoded JSON serialization of ListFolderCursorDto
 */
export declare type ListFolderCursor = Opaque<string, "ListFolderCursor">;
export declare function ListFolderCursor(value: string): ListFolderCursor;
export declare type ListFolderLimit = Opaque<number, "ListFolderLimit">;
export declare function ListFolderLimit(value: number): ListFolderLimit;
export declare type ListFolderDescendantsLimit = Opaque<number, "ListFolderDescendantsLimit">;
export declare function ListFolderDescendantsLimit(value: number): ListFolderDescendantsLimit;
export declare type FolderDescription = Opaque<string, "FolderDescription">;
export declare function FolderDescription(value: string): FolderDescription;
/**
 * The full path, that appears after target ID, for a target request. It includes the file path (to request from the
 * target -- called the 'UpstreamOriginalFilePath' below), the transformation slug, and optionally the path artifact.
 */
export declare type FolderRequestPath = Opaque<string, "FolderRequestPath">;
export declare function FolderRequestPath(value: string): FolderRequestPath;
/**
 * May be empty string `""`.
 * Cannot contain `/`.
 */
export declare type FolderName = Opaque<string, "FolderName">;
export declare function FolderName(value: string): FolderName;
/**
 * Folder name, with a "/" suffix. Used to sort folder names consistently with S3.
 */
export declare type FolderNameSuffixed = Opaque<string, "FolderNameSuffixed">;
export declare function FolderNameSuffixed(value: string): FolderNameSuffixed;
/**
 * Folder path, with a "/" suffix. Used to sort folder paths consistently with S3.
 */
export declare type FolderPathSuffixed = Opaque<string, "FolderPathSuffixed">;
export declare function FolderPathSuffixed(value: string): FolderPathSuffixed;
/**
 * May be empty string "".
 * Cannot contain "/".
 */
export declare type FileName = Opaque<string, "FileName">;
export declare function FileName(value: string): FileName;
/**
 * If starts with '/' has the same semantics and treatment as a 'FilePath'.
 *
 * Else must be combined with a base folder through 'FolderPathUtils.combine'.
 *
 * CAVEAT: this will cause problems as it will prevent you referencing a file from a sibling unnamed directory (as the
 * relative path will begin with a '/' and will look like an absolute path...). This will just have to be a limitation,
 * in that certain parts of the Upload.io system will mistreat these edge-case relative paths as absolute paths (e.g.
 * image paths for watermarks). In practice, this should be limited to a few places, and we can always warn against
 * unnamed folders, saying they have limited support.
 *
 * May contain '..' although these don't traverse and are just part of the file path (like how S3 keys can contain '..').
 */
export declare type RelativeOrAbsoluteFilePath = Opaque<string, "RelativeOrAbsoluteFilePath">;
export declare function RelativeOrAbsoluteFilePath(value: string): RelativeOrAbsoluteFilePath;
export declare type RelativeOrAbsoluteFolderPath = Opaque<string, "RelativeOrAbsoluteFolderPath">;
export declare function RelativeOrAbsoluteFolderPath(value: string): RelativeOrAbsoluteFolderPath;
/**
 * Excludes leading "/".
 *
 * May contain other "/" including a trailing "/" if this refers to a nameless file.
 *
 * See 'RelativeOrAbsoluteFilePath' for caveats and other semantics.
 */
export declare type RelativeFilePath = Opaque<string, "RelativeFilePath">;
export declare function RelativeFilePath(value: string): RelativeFilePath;
/**
 * Path to a folder under management by Upload (either stored on Upload, or externally via another storage layer).
 *
 * Excludes trailing "/" (unless the leaf folder name is empty string, or this is the root path "/").
 * Includes leading "/"
 *
 * See 'FileOrFolderPath' below for examples.
 */
export declare type FolderPath = Opaque<string, "FolderPath">;
export declare function FolderPath(value: string): FolderPath;
export declare type ApiKeyId = Opaque<string, "ApiKeyId">;
export declare function ApiKeyId(value: string): ApiKeyId;
/**
 * Path to a file under management by Upload (either stored on Upload, or externally via another storage layer).
 *
 * See 'FileOrFolderPath' below for examples.
 */
export declare type FilePath = Opaque<string, "FilePath">;
export declare function FilePath(value: string): FilePath;
/**
 * Unique suffix added to file paths when saving temporary files (to S3) during file transformations.
 *
 * Same value is used throughout a transformation invocation.
 *
 * Value is only unique* within the scope of a file path.
 *
 * *Statistically unique: we don't check for uniqueness, but given temp files only last 24 hours, and the only way to
 * create new items in the space is by running additional transformations on the same file path, we consider it unlikely
 * that a conflict will occur.
 */
export declare type TempNamespace = Opaque<string, "TempNamespace">;
export declare function TempNamespace(value: string): TempNamespace;
export declare type TransformationTrackerId = Opaque<string, "TransformationTrackerId">;
export declare function TransformationTrackerId(value: string): TransformationTrackerId;
export declare type IamRoleArn = Opaque<string, "IamRoleArn">;
export declare function IamRoleArn(value: string): IamRoleArn;
export declare type MediaConvertQueueArn = Opaque<string, "MediaConvertQueueArn">;
export declare function MediaConvertQueueArn(value: string): MediaConvertQueueArn;
export declare type MediaConvertTimecode = Opaque<string, "MediaConvertTimecode">;
export declare function MediaConvertTimecode(value: string): MediaConvertTimecode;
/**
 * Added to items in batch jobs, such that they can be sorted in-memory (as DynamoDB non-deterministically sorts arrays),
 * which allows us to maintain a cursor in the job summary itself to indicate which job item has been processed.
 */
export declare type JobItemIndex = Opaque<number, "JobItemIndex">;
export declare function JobItemIndex(value: number): JobItemIndex;
/**
 * Path to a file or folder under management by Upload (either stored on Upload, or externally via another storage layer).
 *
 * Excludes:
 * - Account ID
 * - Transformation slug.
 *
 * Includes:
 * - Top-level folder (e.g. "/uploads").
 * - The "/" prefix.
 *
 * Examples:
 * - "/uploads/abc1234abc1234fG"                                -- File uploaded to default location
 * - "/example/folder/"                                         -- Apex (i.e. empty string) file name
 * - "/example/path//with/../some?/special:characters"          -- File name with special characters
 * - "/web/https://images.unsplash.com/image.jpg?w=800&h=600"   -- Web folder file name
 */
export declare type FileOrFolderPath = Opaque<string, "FileOrFolderPath">;
export declare function FileOrFolderPath(value: string): FileOrFolderPath;
/**
 * If references a file, then is equivalent to 'FilePath'.
 * If references a folder, then is equivalent to 'FolderPathSuffixed'.
 */
export declare type FileOrFolderPathSortKey = Opaque<string, "FileOrFolderPathSortKey">;
export declare function FileOrFolderPathSortKey(value: string): FileOrFolderPathSortKey;
/**
 * Does NOT contain a "/" prefix.
 * Does NOT include the top-level folder.
 * MAY contain '?' and query params (e.g. for upstream URLs).
 * MAY contain ':' (and in fact may represent an entire URL)
 */
export declare type FolderApiFileUrl = Opaque<string, "FolderApiFileUrl">;
export declare function FolderApiFileUrl(value: string): FolderApiFileUrl;
/**
 * Unique within the scope of a single account only. Not guaranteed to be unique globally. Does not contain the
 * account ID as a prefix, so must accompany an account ID for the purpose of identifying a transformation.
 */
export declare type TransformationDefinitionId = Opaque<string, "TransformationDefinitionId">;
export declare function TransformationDefinitionId(value: string): TransformationDefinitionId;
/**
 * Query string without the "?" prefix.
 */
export declare type QueryStringNoPrefix = Opaque<string, "QueryStringNoPrefix">;
export declare function QueryStringNoPrefix(value: string): QueryStringNoPrefix;
export declare type TransformationDescription = Opaque<string, "TransformationDescription">;
export declare function TransformationDescription(value: string): TransformationDescription;
export declare type TransformationUrlSlug = Opaque<string, "TransformationUrlSlug">;
export declare function TransformationUrlSlug(value: string): TransformationUrlSlug;
export declare type TransformationUrlSlugPattern = Opaque<string, "TransformationUrlSlugPattern">;
export declare function TransformationUrlSlugPattern(value: string): TransformationUrlSlugPattern;
export declare type RuleDescription = Opaque<string, "RuleDescription">;
export declare function RuleDescription(value: string): RuleDescription;
export declare type RuleName = Opaque<string, "RuleName">;
export declare function RuleName(value: string): RuleName;
export declare type RuleErrorMessage = Opaque<string, "RuleErrorMessage">;
export declare function RuleErrorMessage(value: string): RuleErrorMessage;
export declare type FileExpiredMessage = Opaque<string, "FileExpiredMessage">;
export declare function FileExpiredMessage(value: string): FileExpiredMessage;
/**
 * Can include a wildcard * suffix.
 */
export declare type TagScope = Opaque<string, "TagScope">;
export declare function TagScope(value: string): TagScope;
export declare type MimeType = Opaque<string, "MimeType">;
export declare function MimeType(value: string): MimeType;
export declare type FileTagName = Opaque<string, "FileTagName">;
export declare function FileTagName(value: string): FileTagName;
export declare type WarmTransformationFunctionLimit = Opaque<number, "WarmTransformationFunctionLimit">;
export declare function WarmTransformationFunctionLimit(value: number): WarmTransformationFunctionLimit;
export declare type HotTransformationFunctionLimit = Opaque<number, "HotTransformationFunctionLimit">;
export declare function HotTransformationFunctionLimit(value: number): HotTransformationFunctionLimit;
export declare type BigSizeInBytes = Opaque<string, "BigSizeInBytes">;
export declare function BigSizeInBytes(value: string): BigSizeInBytes;
/**
 * An 'object author' is the name of the application that created/updated the object.
 */
export declare type ApplicationName = Opaque<string, "ApplicationName">;
export declare function ApplicationName(value: string): ApplicationName;
/**
 * An 'object author version' is the version the author application was at (see above) when it performed the create/update.
 */
export declare type ApplicationVersion = SemanticVersion;
export declare type SemanticVersion = Opaque<string, "SemanticVersion">;
export declare function SemanticVersion(value: string): SemanticVersion;
export declare type ObjectVersion = Opaque<number, "ObjectVersion">;
export declare function ObjectVersion(value: number): ObjectVersion;
export declare function ObjectVersionInc(value: ObjectVersion): ObjectVersion;
export declare type Jwt = Opaque<string, "Jwt">;
export declare function Jwt(value: string): Jwt;
export declare type EpochMillis = Opaque<number, "EpochMillis">;
export declare function EpochMillis(value: number): EpochMillis;
export declare type EpochSeconds = Opaque<number, "EpochSeconds">;
export declare function EpochSeconds(value: number): EpochSeconds;
export declare type EpochDays = Opaque<number, "EpochDays">;
export declare function EpochDays(value: number): EpochDays;
export declare type EpochMonths = Opaque<number, "EpochMonths">;
export declare function EpochMonths(value: number): EpochMonths;
export declare type PageSize = Opaque<number, "PageSize">;
export declare function PageSize(value: number): PageSize;
export declare type ContinuationToken = Opaque<string, "ContinuationToken">;
export declare function ContinuationToken(value: string): ContinuationToken;
export declare type ApiKeyDescription = Opaque<string, "ApiKeyDescription">;
export declare function ApiKeyDescription(value: string): ApiKeyDescription;
export declare type PublicApiKey = Opaque<string, "PublicApiKey">;
export declare function PublicApiKey(value: string): PublicApiKey;
export declare type SecretApiKey = Opaque<string, "SecretApiKey">;
export declare function SecretApiKey(value: string): SecretApiKey;
export declare type DomainName = Opaque<string, "DomainName">;
export declare function DomainName(value: string): DomainName;
/**
 * The user's custom CNAME is the 'CustomDomainName' (e.g. "example.com") and the domain it points to is the 'CustomDomainNameTargetDomain' (e.g. "xyz.upcdn.io").
 */
export declare type CustomDomainName = Opaque<string, "CustomDomainName">;
export declare function CustomDomainName(value: string): CustomDomainName;
/**
 * The user's custom CNAME is the 'CustomDomainName' (e.g. "example.com") and the domain it points to is the 'CustomDomainNameTargetDomain' (e.g. "xyz.upcdn.io").
 */
export declare type CustomDomainNameTargetDomain = Opaque<string, "CustomDomainNameTargetDomain">;
export declare function CustomDomainNameTargetDomain(value: string): CustomDomainNameTargetDomain;
export declare type PluginDescription = Opaque<string, "PluginDescription">;
export declare function PluginDescription(value: string): PluginDescription;
export declare type TemplateCategory = Opaque<string, "TemplateCategory">;
export declare function TemplateCategory(value: string): TemplateCategory;
export declare type TemplateKey = Opaque<string, "TemplateKey">;
export declare function TemplateKey(value: string): TemplateKey;
export declare type TemplateName = Opaque<string, "TemplateName">;
export declare function TemplateName(value: string): TemplateName;
export declare type TemplateDescription = Opaque<string, "TemplateDescription">;
export declare function TemplateDescription(value: string): TemplateDescription;
export declare type TemplateParamDefault = Opaque<string, "TemplateParamDefault">;
export declare function TemplateParamDefault(value: string): TemplateParamDefault;
export declare type TemplateParamDescription = Opaque<string, "TemplateParamDescription">;
export declare function TemplateParamDescription(value: string): TemplateParamDescription;
export declare type TemplateParamLabel = Opaque<string, "TemplateParamLabel">;
export declare function TemplateParamLabel(value: string): TemplateParamLabel;
export declare type TemplateParamPlaceholder = Opaque<string, "TemplateParamPlaceholder">;
export declare function TemplateParamPlaceholder(value: string): TemplateParamPlaceholder;
export declare type IpAddressV4 = Opaque<string, "IpAddressV4">;
export declare function IpAddressV4(value: string): IpAddressV4;
